AudioPlayInfo class

Class for audio message

Constructors

AudioPlayInfo({required AudioPlayType type, required String path, required String msgID, required int totalSecond, required String convKey, required int convType})

Properties

convKey → String
=== conversation key ===
final
convType → int
=== conversation type ===
final
hashCode → int
The hash code for this object.
no setterinherited
msgID → String
=== audio message ID ===
final
path → String
=== audio path ===
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSecond → int
=== audio total seconds ===
final
type → AudioPlayType
=== audio type ===
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited