CurrentPlayAudioInfo class

Class for currently played audio information

Constructors

CurrentPlayAudioInfo({required double progress, required AudioPlayInfo playInfo, required bool isCompleted, required bool isPaused})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isCompleted → bool
=== value for playing is completed ===
final
isPaused → bool
=== value for audio is paused ===
final
playInfo → AudioPlayInfo
=== audio info ===
final
progress → double
=== progress ===
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited