TencentCloudChatThemeModel class

A class that contains the core theme model for TencentCloudChat .

Constructors

TencentCloudChatThemeModel({TencentCloudChatThemeColors? lightTheme, TencentCloudChatThemeColors? darkTheme, TencentCloudChatTextStyle? textStyle})
Creates a new TencentCloudChatThemeModel with the given light and dark theme colors, and text styles.

Properties

darkTheme ↔ TencentCloudChatThemeColors
Getter for the dark theme colors.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lightTheme ↔ TencentCloudChatThemeColors
Getter for the light theme colors.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle ↔ TencentCloudChatTextStyle
Getter for the text styles.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited