TencentCloudChatCallbacks class

Constructors

TencentCloudChatCallbacks({OnTencentCloudChatSDKFailedCallback? onTencentCloudChatSDKFailedCallback, OnTencentCloudChatUIKitUserNotificationEvent? onTencentCloudChatUIKitUserNotificationEvent, V2TimSDKListener? onTencentCloudChatSDKEvent})

Properties

hashCode → int
The hash code for this object.
no setterinherited
onSDKEvent → V2TimSDKListener?
final
onSDKFailed ↔ OnTencentCloudChatSDKFailedCallback?
getter/setter pair
onUserNotificationEvent ↔ OnTencentCloudChatUIKitUserNotificationEvent?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

componentName ↔ String
getter/setter pair