TencentCloudChatComponentBuilders class

A class containing custom UI builders for further customizing each modular UI component on a global scale.

Constructors

TencentCloudChatComponentBuilders({TencentCloudChatComponentBuilder? conversationBuilder, TencentCloudChatComponentBuilder? messageBuilder, TencentCloudChatComponentBuilder? contactBuilder, TencentCloudChatComponentBuilder? userProfileBuilder, TencentCloudChatComponentBuilder? groupProfileBuilder})
Constructs a new instance of TencentCloudChatComponentBuilders with the specified custom builders for each component.
const

Properties

contactBuilder → TencentCloudChatComponentBuilder?
Specify an instance of TencentCloudChatContactBuilders for customizing the contact component.
final
conversationBuilder → TencentCloudChatComponentBuilder?
Specify an instance of TencentCloudChatConversationBuilders for customizing the conversation component.
final
groupProfileBuilder → TencentCloudChatComponentBuilder?
Specify an instance of TencentCloudChatGroupProfileBuilders for customizing the group profile component.
final
hashCode → int
The hash code for this object.
no setterinherited
messageBuilder → TencentCloudChatComponentBuilder?
Specify an instance of TencentCloudChatMessageBuilders for customizing the message component.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userProfileBuilder → TencentCloudChatComponentBuilder?
Specify an instance of TencentCloudChatUserProfileBuilders for customizing the user profile component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited