TencentCloudChatComponentEventHandlers class

The event handlers for events related to UI components for each modular UI component, affecting globally.

Constructors

TencentCloudChatComponentEventHandlers({TencentCloudChatConversationEventHandlers? conversationEventHandlers, TencentCloudChatMessageEventHandlers? messageEventHandlers, TencentCloudChatContactEventHandlers? contactEventHandlers, TencentCloudChatGroupProfileEventHandlers? groupProfileEventHandlers})
Constructs a new instance of TencentCloudChatComponentEventHandlers with the specified event handlers for each component.
const

Properties

contactEventHandlers → TencentCloudChatContactEventHandlers?
final
conversationEventHandlers → TencentCloudChatConversationEventHandlers?
final
groupProfileEventHandlers → TencentCloudChatGroupProfileEventHandlers?
final
hashCode → int
The hash code for this object.
no setterinherited
messageEventHandlers → TencentCloudChatMessageEventHandlers?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited