TencentCloudChatInitComponentsRelated class

Constructors

TencentCloudChatInitComponentsRelated({required List<TencentCloudChatModularUIPackageRegister> usedComponentsRegister, TencentCloudChatComponentConfigs? componentConfigs, TencentCloudChatComponentBuilders? componentBuilders, TencentCloudChatComponentEventHandlers? componentEventHandlers})
Constructs a new instance of TencentCloudChatInitComponentsRelated with the related configurations for components when calling initUIKit.
const

Properties

componentBuilders → TencentCloudChatComponentBuilders?
The builder for further customizing the UI for each modular UI component, affecting globally.
final
componentConfigs → TencentCloudChatComponentConfigs?
The configuration for each modular UI component, affecting globally.
final
componentEventHandlers → TencentCloudChatComponentEventHandlers?
The event handlers for events related to UI components for each modular UI component, affecting globally.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usedComponentsRegister → List<TencentCloudChatModularUIPackageRegister>
List of registration functions for the components used in the Chat UIKit.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited