TencentCloudChatInitOptions class

This class represents the initial options for Tencent Cloud Chat.

Constructors

TencentCloudChatInitOptions({required int sdkAppID, required String userID, required String userSig, @Deprecated('Please use `onTencentCloudChatSDKEvent` from the `callbacks` field within `TencentCloudChatCallbacks` when calling `initUIKit` instead.') V2TimSDKListener? sdkListener})
Constructor for TencentCloudChatInitOptions.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkAppID → int
The Chat SDKAppID.
final
sdkListener → V2TimSDKListener?
final
userID → String
The user ID for the Chat SDK.
final
userSig → String
The user signature for the Chat SDK.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited