TencentCloudChatPluginItem class

Constructors

TencentCloudChatPluginItem({required String name, required TencentCloudChatPlugin pluginInstance, Map<String, dynamic>? initData, TencentCloudChatPluginTapFn? tapFn})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
initData → Map<String, dynamic>?
final
name → String
final
pluginInstance → TencentCloudChatPlugin
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tapFn → TencentCloudChatPluginTapFn?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited