TencentCloudChat class

Properties

cache → TencentCloudChatCacheGlobal
final
callbacks → TencentCloudChatCallbacksTrigger
final
chatController → TencentCloudChatCoreController
final
chatSDKInstance → TencentCloudChatSDK
final
dataInstance → TencentCloudChatData
final
eventBusInstance → TencentCloudChatEventBus
final
hashCode → int
The hash code for this object.
no setterinherited
logInstance → TencentCloudChatLog
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

controller → TencentCloudChatCoreController
no setter
instance → TencentCloudChat
no setter