V2TimFriendApplication class

V2TimFriendApplication

Constructors

V2TimFriendApplication({required String userID, String? nickname, String? faceUrl, int? addTime, String? addSource, String? addWording, required int type})
V2TimFriendApplication.fromJson(Map json)
V2TimFriendApplication.fromJsonForCallback(Map json)
给加好友申请回调使用

Properties

addSource ↔ String?
getter/setter pair
addTime ↔ int?
getter/setter pair
addWording ↔ String?
getter/setter pair
faceUrl ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nickname ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ int
getter/setter pair
userID ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toJsonForCallback() → Map<String, dynamic>
给加好友申请回调使用
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited