V2TimMemberEnter class

V2TimMemberEnter

Constructors

V2TimMemberEnter({required String groupID, List<V2TimGroupMemberInfo?>? memberList})
V2TimMemberEnter.fromJson(Map json)

Properties

groupID ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
memberList ↔ List<V2TimGroupMemberInfo?>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toLogString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited