DownloadMessageQueueData class

Constructors

DownloadMessageQueueData({required String convID, required int conversationType, required String key, required String msgID, required int messageType, required int imageType, required bool isSnapshot})

Properties

conversationType → int
=== conversation type ===
final
convID → String
final
currentDownloadSize ↔ int
=== current download size ===
getter/setter pair
downloadFinish ↔ bool
=== is download finished ===
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageType → int
=== image type ===
final
isSnapshot → bool
=== value that check whether image is snapshot ===
final
key → String
=== message key, could be user ID or group ID ===
final
messageType → int
=== message type ===
final
msgID → String
=== message ID ===
final
path ↔ String?
=== download message's path ===
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapPath ↔ String?
=== snapshot path ===
getter/setter pair
totalSize ↔ int
=== total message size ===
getter/setter pair

Methods

getUniqueueKey() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited