CallingMessage class

Constructors

CallingMessage()

Properties

actionType ↔ int?
getter/setter pair
cmd ↔ String?
command for invitation
getter/setter pair
direction → CallMessageDirection
no setter
excludeFromHistoryMessage ↔ String?
Is call excluded from history messages
getter/setter pair
groupID ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inviteeList ↔ List<String>?
Invitees list of invitee
getter/setter pair
inviteID ↔ String?
Invitation ID
getter/setter pair
inviter ↔ String?
Inviter invitor
getter/setter pair
isCallingSignal ↔ bool
getter/setter pair
participantType → CallParticipantType
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamMediaType → CallStreamMediaType
no setter
timeout ↔ int?
Call duration
getter/setter pair
v2timMessage ↔ V2TimMessage?
getter/setter pair

Methods

getContent() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getCallMessage(V2TimMessage v2timMessage) → CallingMessage?
Returns a CallingMessage data from V2TimMessage
getShowTime(int seconds) → dynamic
This function get time from passed seconds Return 2 digits formated minutes and seconds mm:ss
isGroupCallEndExist(CallingMessage callMsg) → dynamic
This function checks if group call has ended without canceling the call Returns if group call is ended and exists
twoDigits(int n) → String
Returns 2 digits of number Example: if passed 1, returns "01", if passed 10, returns "10"